# pubmed_lib

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install pubmed_lib
```

## How to use

This library has the basic functionalities to retreive data from pubmed
search to be used with Langchain for Q&A systems, it is a simple wrapper
from the Biopython

First you need to create a search object, with the default parameter you
will use in the search

------------------------------------------------------------------------

<a
href="https://github.com/Dmaturana81/pubmed_lib/blob/main/pubmed_lib/search.py#LNone"
target="_blank" style="float:right; font-size:smaller">source</a>

### Search

>      Search (search_tag:str=None, retmax:int=200, retmode:str='xml',
>              sort:str='relevance', mindate:Optional[int]=None,
>              maxdate:Optional[int]=None, idlist:Optional[List[int]]=None,
>              email:str=None, api_key:str=None)

Search class to warp the search and results

Here we will create the object with a max number of results of 10

the search_tag correspondes to the tag where you will do the search, the
options available are the following:

``` python
for k in SEARCH_TAGS.keys():
    print(f"{k}")
```

    Affiliation
    All Fields
    Article Identifier
    Author
    Author Identifier
    EC/RN Number
    First Author Name
    Full Author Name
    Full Investigator Name
    Grant Number
    Investigator
    Journal
    Last Author Name
    Location ID
    MeSH Major Topic
    MeSH Subheadings
    MeSH Terms
    Other Term
    PMID
    Subset
    Text Words
    Title
    Title/Abstract

By defaults is setup to search in Title/Abstract

``` python
search = Search(retmax=10)
```

To actually do the search, you need to call the method search and give
the query

------------------------------------------------------------------------

<a
href="https://github.com/Dmaturana81/pubmed_lib/blob/main/pubmed_lib/search.py#LNone"
target="_blank" style="float:right; font-size:smaller">source</a>

### Search.search

>      Search.search (query:str)

It receive a query to be searched in pubmed and return the handler of
the search

|       | **Type** | **Details**                  |
|-------|----------|------------------------------|
| query | str      | Query to be search in pubmed |

``` python
results = search.search('Bi-functional degraders in cancer')
```

``` python
results
```

    ['35285613', '33672989', '23749892', '17310834', '35644005', '16870428', '29587668', '21269262', '25685909', '27815492']

to fetch the results you need to call the fetch_details method, and pass
the list of pubmedIds retreive previously

``` python
articles = search.fetch_details(results)
```

This will give you the xml data retreived from pubmed

In order to retreive the parsed resutls, you should use the method
results

------------------------------------------------------------------------

<a
href="https://github.com/Dmaturana81/pubmed_lib/blob/main/pubmed_lib/search.py#LNone"
target="_blank" style="float:right; font-size:smaller">source</a>

### Search.results

>      Search.results (query:str)

Method that do the search and retrieve a generator with all the
infomration of the articles

|             | **Type**      | **Details**                  |
|-------------|---------------|------------------------------|
| query       | str           | Term to be queried in pubmed |
| **Returns** | **Generator** |                              |

``` python
results = search.results('Bi-functional degraders in cancer')
```

``` python
res = list(results)
```

``` python
res[0]
```

    Result(pubmed='35285613', pmc=None, doi='10.1021/acsabm.1c01216', pii=None, abstract="Gold nanorods (AuNRs) remain well-developed inorganic nanocarriers of small molecules for a plethora of biomedical and therapeutic applications. However, the delivery of therapeutic proteins using AuNRs with high protein loading capacity (LC), serum stability, excellent target specificity, and minimal off-target protein release is not known. Herein, we report two bi-functional AuNR-protein nanoconjugates, AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub>, supramolecularly coated with folic acid-modified BSA (BSA<sub>FA</sub>) acting as biomimetic protein corona to demonstrate targeted cytosolic delivery of enhanced green fluorescent protein (EGFP) and therapeutic ribonuclease A enzyme (RNase A) in their functional forms. AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub> exhibit high LCs of ∼42 and ∼54%, respectively, increased colloidal stability, and rapid protein release in the presence of biological thiols. As a nanocarrier, AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub> show resistance to corona formation in high-serum media even after 24 h, guaranteeing a greater circulation lifetime. Folate receptor-targeting BSA<sub>FA</sub> on the AuNR surface facilitates the receptor-mediated internalization, followed by the release of EGFP and RNase A in HT29 cells. The green fluorescence dispersed throughout the cell's cytoplasm indicates successful cytosolic delivery of EGFP by AuNR@EGFP-BSA<sub>FA</sub>. AuNR@RNaseA-BSA<sub>FA</sub>-mediated therapeutic RNase A delivery in multicellular 3D spheroids of HT29 cells exhibits a radical reduction in the cellular RNA fluorescence intensity to 38%, signifying RNA degradation and subsequent cell death. The versatile nanoformulation strategy in terms of the anisotropic particle morphology, protein type, and ability for targeted delivery in the functional form makes the present AuNR-protein nanoconjugates a promising platform for potential application in cancer management.", autorlist=[Autor(Fname='Namita', Lname='Jaiswal', name='Namita Jaiswal', initials='N', emails='', affiliations='Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.;Material Processing And Microsystem Laboratory, Csir─Central Mechanical Engineering Research Institute, Durgapur 713209, India.', identifier=''), Autor(Fname='Sudeshna', Lname='Halder', name='Sudeshna Halder', initials='S', emails='', affiliations='Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.', identifier=''), Autor(Fname='Nibedita', Lname='Mahata', name='Nibedita Mahata', initials='N', emails='', affiliations='Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.', identifier=''), Autor(Fname='Nripen', Lname='Chanda', name='Nripen Chanda', initials='N', emails='', affiliations='Material Processing And Microsystem Laboratory, Csir─Central Mechanical Engineering Research Institute, Durgapur 713209, India.', identifier='0000-0002-9902-5595')], title='Bi-Functional Gold Nanorod-Protein Conjugates with Biomimetic BSA@Folic Acid Corona for Improved Tumor Targeting and Intracellular Delivery of Therapeutic Proteins in Colon Cancer 3D Spheroids.', journal='ACS applied bio materials', published=datetime.date(2022, 3, 14), mayorKeys=[], mayorMesh=['Colonic Neoplasms', 'Nanotubes'], minorMesh=['Biomimetics', 'Folic Acid', 'Gold', 'Humans', 'Nanoconjugates', 'Ribonuclease, Pancreatic'])

``` python
res[0].dict()
```

    {'pubmed': '35285613',
     'pmc': None,
     'doi': '10.1021/acsabm.1c01216',
     'pii': None,
     'abstract': "Gold nanorods (AuNRs) remain well-developed inorganic nanocarriers of small molecules for a plethora of biomedical and therapeutic applications. However, the delivery of therapeutic proteins using AuNRs with high protein loading capacity (LC), serum stability, excellent target specificity, and minimal off-target protein release is not known. Herein, we report two bi-functional AuNR-protein nanoconjugates, AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub>, supramolecularly coated with folic acid-modified BSA (BSA<sub>FA</sub>) acting as biomimetic protein corona to demonstrate targeted cytosolic delivery of enhanced green fluorescent protein (EGFP) and therapeutic ribonuclease A enzyme (RNase A) in their functional forms. AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub> exhibit high LCs of ∼42 and ∼54%, respectively, increased colloidal stability, and rapid protein release in the presence of biological thiols. As a nanocarrier, AuNR@EGFP-BSA<sub>FA</sub> and AuNR@RNaseA-BSA<sub>FA</sub> show resistance to corona formation in high-serum media even after 24 h, guaranteeing a greater circulation lifetime. Folate receptor-targeting BSA<sub>FA</sub> on the AuNR surface facilitates the receptor-mediated internalization, followed by the release of EGFP and RNase A in HT29 cells. The green fluorescence dispersed throughout the cell's cytoplasm indicates successful cytosolic delivery of EGFP by AuNR@EGFP-BSA<sub>FA</sub>. AuNR@RNaseA-BSA<sub>FA</sub>-mediated therapeutic RNase A delivery in multicellular 3D spheroids of HT29 cells exhibits a radical reduction in the cellular RNA fluorescence intensity to 38%, signifying RNA degradation and subsequent cell death. The versatile nanoformulation strategy in terms of the anisotropic particle morphology, protein type, and ability for targeted delivery in the functional form makes the present AuNR-protein nanoconjugates a promising platform for potential application in cancer management.",
     'autorlist': [{'Fname': 'Namita',
       'Lname': 'Jaiswal',
       'name': 'Namita Jaiswal',
       'initials': 'N',
       'emails': '',
       'affiliations': 'Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.;Material Processing And Microsystem Laboratory, Csir─Central Mechanical Engineering Research Institute, Durgapur 713209, India.',
       'identifier': ''},
      {'Fname': 'Sudeshna',
       'Lname': 'Halder',
       'name': 'Sudeshna Halder',
       'initials': 'S',
       'emails': '',
       'affiliations': 'Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.',
       'identifier': ''},
      {'Fname': 'Nibedita',
       'Lname': 'Mahata',
       'name': 'Nibedita Mahata',
       'initials': 'N',
       'emails': '',
       'affiliations': 'Department Of Biotechnology, National Institute Of Technology Durgapur, Durgapur 713209, India.',
       'identifier': ''},
      {'Fname': 'Nripen',
       'Lname': 'Chanda',
       'name': 'Nripen Chanda',
       'initials': 'N',
       'emails': '',
       'affiliations': 'Material Processing And Microsystem Laboratory, Csir─Central Mechanical Engineering Research Institute, Durgapur 713209, India.',
       'identifier': '0000-0002-9902-5595'}],
     'title': 'Bi-Functional Gold Nanorod-Protein Conjugates with Biomimetic BSA@Folic Acid Corona for Improved Tumor Targeting and Intracellular Delivery of Therapeutic Proteins in Colon Cancer 3D Spheroids.',
     'journal': 'ACS applied bio materials',
     'published': datetime.date(2022, 3, 14),
     'mayorKeys': [],
     'mayorMesh': ['Colonic Neoplasms', 'Nanotubes'],
     'minorMesh': ['Biomimetics',
      'Folic Acid',
      'Gold',
      'Humans',
      'Nanoconjugates',
      'Ribonuclease, Pancreatic']}
